/**
 * Class with auxiliary functions.
 */

package ru.utility;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.util.Properties;
import ru.CryptoPro.JCPxml.xmldsig.JCPXMLDSigInit;

public class SpecUtility {
	
	// All properties
	private static Properties props = new Properties();
	// Default properties. Alternative configuration is wss40 (+ our own variables related to
	// WSS4J files in /keys directory: 'wss40' is valid, 'wss40rev' is revoked)
	public static final String DEFAULT_CRYPTO_PROPERTIES = System.getProperty("user.dir") + 
							"/WebContent/resources/crypto.properties";
	public static String DEFAULT_STORETYPE = "HDImageStore";
	public static String DEFAULT_KEYSTORE = null;
	public static String DEFAULT_ALIAS = "bla-bla-bla";
	public static char[] DEFAULT_PASSWORD = null;
	public static String DEFAULT_CERT_FILE = null;
	public static String DEFAULT_CA_FILE = null;
	public static String DEFAULT_CRL_FILE = null;
	
	// Load all settings from crypto.properties
	static {
		
		try {
			
			props.load(new FileInputStream(DEFAULT_CRYPTO_PROPERTIES));
			
			// Standard WSS4J variables
			DEFAULT_STORETYPE = props.getProperty("org.apache.ws.security.crypto.merlin.keystore.type");
			DEFAULT_KEYSTORE = props.getProperty("org.apache.ws.security.crypto.merlin.file");
			DEFAULT_ALIAS = props.getProperty("org.apache.ws.security.crypto.merlin.keystore.alias");
			
			String password = props.getProperty("org.apache.ws.security.crypto.merlin.keystore.password");
			if (password != null) {
				DEFAULT_PASSWORD = password.toCharArray();
			}
			
			// Our own variables
			DEFAULT_CERT_FILE = props.getProperty("cert.file");
			DEFAULT_CA_FILE = props.getProperty("ca.file");
			DEFAULT_CRL_FILE = props.getProperty("crl.file");

		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
		
	/**
	 * Functions initializes XML JCP.
	 */
	public static void initJCP() {
		
		if(!JCPXMLDSigInit.isInitialized())
    		JCPXMLDSigInit.init();
		
		System.setProperty("com.ibm.security.enableCRLDP", "false");
	}

	/**
	 * Function loads store information from key store.
	 * @param storeType - type of key store (HDImageStore, JKS, PKCS12).
	 * @param store - store file.
	 * @param storePassword - password to store.
	 * @return loaded key store.
	 * @throws KeyStoreException
	 * @throws NoSuchAlgorithmException
	 * @throws CertificateException
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static KeyStore loadKeyStore( String storeType, File store, char[] storePassword ) 
	throws KeyStoreException, NoSuchAlgorithmException, CertificateException, 
		FileNotFoundException, IOException {

		KeyStore keyStore = KeyStore.getInstance(storeType);
		FileInputStream inputStream = null;

		if (store != null)
			inputStream = new FileInputStream(store);

		keyStore.load( keyStore == null ? null : inputStream, storePassword );
		return keyStore;		 
	}
}
