/*
 * Class provides generating and verifying of signature. For wss4j 1.5.11 only.
 */

package ru.wss4j1_5_11.manager;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.util.Properties;
import java.util.Vector;
import org.apache.axis.message.SOAPEnvelope;
import org.apache.ws.security.WSConstants;
import org.apache.ws.security.WSSecurityEngine;
import org.apache.ws.security.WSSecurityEngineResult;
import org.apache.ws.security.WSSecurityException;
import org.apache.ws.security.components.crypto.Crypto;
import org.apache.ws.security.components.crypto.CryptoFactory;
import org.apache.ws.security.message.WSSecHeader;
import org.apache.ws.security.message.WSSecSignature;
import org.apache.ws.security.util.WSSecurityUtil;
import org.w3c.dom.Document;
import ru.manager.SignatureManager;
import ru.utility.SOAPUtility;

public class SOAPXMLSignatureManager_1_5_11 extends SignatureManager {
	
	private WSSecurityEngine secEngine = new WSSecurityEngine();
	private Crypto crypto = null;
	private String alias;
	private char[] keyPassword = null;
	private Properties props = new Properties();
	
	public SOAPXMLSignatureManager_1_5_11(String propertyFile, String alias, char[] password) 
	throws ClassNotFoundException, KeyStoreException, NoSuchAlgorithmException, CertificateException {
		
		props.clear();
		this.alias = alias;
		this.keyPassword = password;
		
		try {
			// Load properties (store type, key alias etc)
			props.load(new FileInputStream(propertyFile));
			// Create object (Merlin) to sign and verify SOAP XML messages. It uses crypto.properties and
			// key store must to contain certificate and key
			crypto = CryptoFactory.getInstance(props);
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Function signs XML SOAP document.
	 * @param docStr - XML SOAP string.
	 * @return signed document.
	 */
	public Document signDoc(String docStr) {
		
		Document signedDoc = null;
		
		try {
			SOAPEnvelope unsignedEnvelope = SOAPUtility.getSOAPEnvelopeFromString(docStr);
			// Prepare object to sign secured message
			WSSecSignature sign = new WSSecSignature();
			
			// Set properties: alias, password, algorithm etc.
			String pswrd = null;
			if (keyPassword != null) {
				pswrd = new String(keyPassword);
			}
	        sign.setUserInfo(alias, pswrd);
	        
	        sign.setKeyIdentifierType(WSConstants.BST_DIRECT_REFERENCE);
	        sign.setSignatureAlgorithm(ru.CryptoPro.JCPxml.Consts.URI_GOST_SIGN);
	        sign.setDigestAlgo(ru.CryptoPro.JCPxml.Consts.URI_GOST_DIGEST);
	        
	        Document sourceDoc = unsignedEnvelope.getAsDocument();
	        WSSecHeader secHeader = new WSSecHeader();
	        secHeader.insertSecurityHeader(sourceDoc);
	        // Sign document
	        signedDoc = sign.build(sourceDoc, crypto, secHeader);
			
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return signedDoc;
		
	}
	
	/**
	 * Function verifies a signature in SOAP XML document.
	 * @param doc - verifiable SOAP XML document with signature.
	 * @param printCert - option to print certificate.
	 * @return object with result.
	 * @throws Exception
	 */
	public boolean verifyDoc(Document signedDoc, boolean printCert) {
		
		boolean result = false;
		
		if (signedDoc == null)
			return false;
		
		try {
			// Verify signature
			Vector<?> results = secEngine.processSecurityHeader(signedDoc, null, null, crypto);
			// Ensure actionResult != null
			WSSecurityEngineResult actionResult = WSSecurityUtil.fetchActionResult(results, WSConstants.SIGN);
			result = (actionResult != null);
			
			// Print signer cerificate
			if (printCert) {
				System.out.println(actionResult.getCertificate());
			}
			
		} catch (WSSecurityException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return result;
	}

	/**
	 * Function returns SOAP message.
	 */
	public String getMessage() {
		return SOAPUtility.SOAPMSG;
	}
}
