/**
 * Class for signing & verifying of SOAP XML document.
 */

package ru.wss4j1_5_11.tests;

import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import org.w3c.dom.Document;
import ru.manager.SignatureManager;
import ru.utility.SpecUtility;
import ru.wss4j1_5_11.manager.SOAPXMLSignatureManager_1_5_11;

public class WSS4J_SignVerifySOAP {

	/**
	 * @param args
	 * @throws ClassNotFoundException 
	 * @throws CertificateException 
	 * @throws NoSuchAlgorithmException 
	 * @throws KeyStoreException 
	 * @throws Exception 
	 */
	public static void main(String[] args) throws KeyStoreException, NoSuchAlgorithmException, 
	CertificateException, ClassNotFoundException {

		// Initialize JCP
		SpecUtility.initJCP();
		
		System.out.println("###### Test WSS4J_SignVerifySOAP 1.5.11 is begun ######");
		
		// Load key store
		SignatureManager manager = 
			new SOAPXMLSignatureManager_1_5_11(SpecUtility.DEFAULT_CRYPTO_PROPERTIES, 
				SpecUtility.DEFAULT_ALIAS, SpecUtility.DEFAULT_PASSWORD);
		
		// Sign XML SOAP document
		Document signedDoc = manager.signDoc(manager.getMessage());
        String outputString = org.apache.ws.security.util.XMLUtils.PrettyDocumentToString(signedDoc);
        System.out.println("Signed document: ");
        System.out.println(outputString);
		
        // Verify signature in XML SOAP document
        boolean printCert = true;
        boolean result = manager.verifyDoc(signedDoc, printCert);
        System.out.println("\nVerified: " + result);
		
		System.out.println("###### Test WSS4J_SignVerifySOAP is finished ######");
	}
}
